@@ -51,6 +51,8 @@ class UrlType(UniqueSet, enum.Enum):
     URL_DISK_QCOW2 = {
         # generic data
         "application/octet-stream",
+        # qcow2 files on some mirrors
+        "application-x-qemu-disk",
         # qcow2 files on fedoraproject.org mirrors; similar issue of
         # https://pagure.io/fedora-infrastructure/issue/10766
         "application/x-troff-man",
@@ -68,7 +70,10 @@ class UrlType(UniqueSet, enum.Enum):
         # image manifest
         "application/vnd.docker.distribution.manifest.v1+json",
     }
-    URL_KERNEL = {}
+    URL_KERNEL = {
+        # generic data
+        "application/octet-stream",
+    }
     URL_TREE = {
         # HTML page of file listing
         "text/html",
